@@ -30,7 +30,9 @@
 #include "ui_krenameplugins.h"
 #include "ui_krenamefilename.h"
 
+#include <QAction>
 #include <QIcon>
+#include <QMenu>
 #include <QPushButton>
 #include <kseparator.h>
 
@@ -134,6 +136,13 @@ KRenameWindow::KRenameWindow(QWidget *parent)
 
     this->setAutoSaveSettings("KRenameWindowSettings", true);
 
+    // If there is a huge entry in the history of filenameTemplate that size
+    // apparently gets used as minimal size of the window. Setting it to some
+    // value here works around that.
+    // https://bugs.kde.org/show_bug.cgi?id=398980
+    // TODO: Find a solution without a magic number
+    setMinimumWidth(200);
+
     // Show the first page in any mode
     showPage(0);
 }
@@ -202,7 +211,8 @@ void KRenameWindow::setupGui()
     m_buttonClose = m_buttons->button(QDialogButtonBox::Close);
     m_buttonClose->setShortcut(QKeySequence(QKeySequence::Quit));
 
-    KHelpMenu *helpMenu = new KHelpMenu(this);
+    KHelpMenu *helpMenu = new KHelpMenu(this, QString(), false);
+    helpMenu->menu()->removeAction(helpMenu->action(KHelpMenu::menuHelpContents));
     m_buttons->button(QDialogButtonBox::Help)->setMenu(helpMenu->menu());
 
     setupSlots();
